        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>0</strong> miembros: 27 <strong>control</strong><br>0,1,2,3,4,5,6,11,12,13,14,15,17,20,22,26,30,32,35,36,37,41,42,43,45,47,48';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 13 <br>19,21,27,29,31,33,34,38,39,44,46,49,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260513 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 11 <br>7,8,9,10,16,18,23,24,25,28,40';}
}
